@@ -23,8 +23,15 @@ import boto3
 
 from braket.annealing.problem import Problem
 from braket.aws.aws_session import AwsSession
+from braket.circuits import Instruction
 from braket.circuits.circuit import Circuit
 from braket.circuits.circuit_helpers import validate_circuit_and_shots
+from braket.circuits.compiler_directives import StartVerbatimBox
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    QubitReferenceType,
+)
 from braket.device_schema import GateModelParameters
 from braket.device_schema.dwave import (
     Dwave2000QDeviceParameters,
@@ -51,6 +58,8 @@ from braket.tasks import (
     PhotonicModelQuantumTaskResult,
     QuantumTask,
 )
+from braket.tracking.tracking_context import broadcast_event
+from braket.tracking.tracking_events import _TaskCompletionEvent
 
 
 class AwsQuantumTask(QuantumTask):
@@ -402,6 +411,14 @@ class AwsQuantumTask(QuantumTask):
             current_metadata["outputS3Directory"] + f"/{AwsQuantumTask.RESULTS_FILENAME}",
         )
         self._result = _format_result(BraketSchemaBase.parse_raw_schema(result_string))
+        task_event = {"arn": self.id, "status": self.state(), "execution_duration": None}
+        try:
+            task_event[
+                "execution_duration"
+            ] = self._result.additional_metadata.simulatorMetadata.executionDuration
+        except AttributeError:
+            pass
+        broadcast_event(_TaskCompletionEvent(**task_event))
         return self._result
 
     def __repr__(self) -> str:
@@ -441,6 +458,10 @@ def _(
     *args,
     **kwargs,
 ) -> AwsQuantumTask:
+    if open_qasm_program.inputs is not None:
+        raise ValueError(
+            "OpenQASM Program inputs are only currently supported in the LocalSimulator."
+        )
     create_task_kwargs.update({"action": open_qasm_program.json()})
     task_arn = aws_session.create_quantum_task(**create_task_kwargs)
     return AwsQuantumTask(task_arn, aws_session, *args, **kwargs)
@@ -490,8 +511,23 @@ def _(
             paradigmParameters=paradigm_parameters
         )
 
+    qubit_reference_type = QubitReferenceType.VIRTUAL
+
+    if disable_qubit_rewiring or Instruction(StartVerbatimBox()) in circuit.instructions:
+        qubit_reference_type = QubitReferenceType.PHYSICAL
+
+    serialization_properties = OpenQASMSerializationProperties(
+        qubit_reference_type=qubit_reference_type
+    )
+
     create_task_kwargs.update(
-        {"action": circuit.to_ir().json(), "deviceParameters": device_parameters.json()}
+        {
+            "action": circuit.to_ir(
+                ir_type=IRType.OPENQASM,
+                serialization_properties=serialization_properties,
+            ).json(),
+            "deviceParameters": device_parameters.json(),
+        }
     )
     task_arn = aws_session.create_quantum_task(**create_task_kwargs)
     return AwsQuantumTask(task_arn, aws_session, *args, **kwargs)
