@@ -21,6 +21,7 @@ from braket.annealing import Problem
 from braket.aws.aws_quantum_task import AwsQuantumTask
 from braket.aws.aws_session import AwsSession
 from braket.circuits import Circuit
+from braket.ir.blackbird import Program as BlackbirdProgram
 from braket.ir.openqasm import Program as OpenQasmProgram
 
 
@@ -42,7 +43,7 @@ class AwsQuantumTaskBatch:
         self,
         aws_session: AwsSession,
         device_arn: str,
-        task_specifications: List[Union[Circuit, Problem, OpenQasmProgram]],
+        task_specifications: List[Union[Circuit, Problem, OpenQasmProgram, BlackbirdProgram]],
         s3_destination_folder: AwsSession.S3DestinationFolder,
         shots: int,
         max_parallel: int,
@@ -57,8 +58,8 @@ class AwsQuantumTaskBatch:
         Args:
             aws_session (AwsSession): AwsSession to connect to AWS with.
             device_arn (str): The ARN of the quantum device.
-            task_specification (Union[Circuit, Problem]): The specification of the task
-                to run on device.
+            task_specification (Union[Circuit, Problem, OpenQasmProgram, BlackbirdProgram]):
+                The specification of the task to run on device.
             s3_destination_folder (AwsSession.S3DestinationFolder): NamedTuple, with bucket
                 for index 0 and key for index 1, that specifies the Amazon S3 bucket and folder
                 to store task results in.
