@@ -41,8 +41,15 @@ from braket.circuits.parameterizable import Parameterizable
 from braket.circuits.qubit import QubitInput
 from braket.circuits.qubit_set import QubitSet, QubitSetInput
 from braket.circuits.result_type import ObservableResultType, ResultType
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    QubitReferenceType,
+    SerializationProperties,
+)
 from braket.circuits.unitary_calculation import calculate_unitary, calculate_unitary_big_endian
-from braket.ir.jaqcd import Program
+from braket.ir.jaqcd import Program as JaqcdProgram
+from braket.ir.openqasm import Program as OpenQasmProgram
 
 SubroutineReturn = TypeVar(
     "SubroutineReturn", Iterable[Instruction], Instruction, ResultType, Iterable[ResultType]
@@ -747,7 +754,8 @@ class Circuit:
         noise: Union[Type[Noise], Iterable[Type[Noise]]],
         target_qubits: Optional[QubitSetInput] = None,
     ) -> Circuit:
-        """Apply `noise` at the beginning of the circuit for every qubit (default) or target_qubits`.
+        """Apply `noise` at the beginning of the circuit for every qubit (default) or
+        target_qubits`.
 
         Only when `target_qubits` is given can the noise be applied to an empty circuit.
 
@@ -1059,25 +1067,104 @@ class Circuit:
         """
         return circuit_diagram_class.build_diagram(self)
 
-    def to_ir(self) -> Program:
+    def to_ir(
+        self,
+        ir_type: IRType = IRType.JAQCD,
+        serialization_properties: SerializationProperties = None,
+    ) -> Union[OpenQasmProgram, JaqcdProgram]:
         """
         Converts the circuit into the canonical intermediate representation.
         If the circuit is sent over the wire, this method is called before it is sent.
 
+        Args:
+            ir_type (IRType): The IRType to use for converting the circuit object to its
+                IR representation.
+            serialization_properties (SerializationProperties): The serialization properties to use
+                while serializing the object to the IR representation. The serialization properties
+                supplied must correspond to the supplied `ir_type`. Defaults to None.
+
         Returns:
-            Program: A Braket quantum circuit description program in JSON format.
+            (Union[OpenQasmProgram, JaqcdProgram]): A representation of the circuit in the
+            `ir_type` format.
+
+        Raises:
+            ValueError: If the supplied `ir_type` is not supported, or if the supplied serialization
+            properties don't correspond to the `ir_type`.
         """
-        ir_instructions = [instruction.to_ir() for instruction in self.instructions]
-        ir_results = [result_type.to_ir() for result_type in self.result_types]
+        if ir_type == IRType.JAQCD:
+            return self._to_jaqcd()
+        elif ir_type == IRType.OPENQASM:
+            if serialization_properties and not isinstance(
+                serialization_properties, OpenQASMSerializationProperties
+            ):
+                raise ValueError(
+                    "serialization_properties must be of type OpenQASMSerializationProperties "
+                    "for IRType.OPENQASM."
+                )
+            return self._to_openqasm(serialization_properties or OpenQASMSerializationProperties())
+        else:
+            raise ValueError(f"Supplied ir_type {ir_type} is not supported.")
+
+    def _to_jaqcd(self) -> JaqcdProgram:
+        jaqcd_ir_type = IRType.JAQCD
+        ir_instructions = [instr.to_ir(ir_type=jaqcd_ir_type) for instr in self.instructions]
+        ir_results = [result_type.to_ir(ir_type=jaqcd_ir_type) for result_type in self.result_types]
         ir_basis_rotation_instructions = [
-            instr.to_ir() for instr in self.basis_rotation_instructions
+            instr.to_ir(ir_type=jaqcd_ir_type) for instr in self.basis_rotation_instructions
         ]
-        return Program.construct(
+        return JaqcdProgram.construct(
             instructions=ir_instructions,
             results=ir_results,
             basis_rotation_instructions=ir_basis_rotation_instructions,
         )
 
+    def _to_openqasm(
+        self, serialization_properties: OpenQASMSerializationProperties
+    ) -> OpenQasmProgram:
+        ir_instructions = self._create_openqasm_header(serialization_properties)
+        openqasm_ir_type = IRType.OPENQASM
+        ir_instructions.extend(
+            [
+                instruction.to_ir(
+                    ir_type=openqasm_ir_type, serialization_properties=serialization_properties
+                )
+                for instruction in self.instructions
+            ]
+        )
+
+        if self.result_types:
+            ir_instructions.extend(
+                [
+                    result_type.to_ir(
+                        ir_type=openqasm_ir_type, serialization_properties=serialization_properties
+                    )
+                    for result_type in self.result_types
+                ]
+            )
+        else:
+            for idx, qubit in enumerate(self.qubits):
+                qubit_target = serialization_properties.format_target(int(qubit))
+                ir_instructions.append(f"b[{idx}] = measure {qubit_target};")
+
+        return OpenQasmProgram.construct(source="\n".join(ir_instructions))
+
+    def _create_openqasm_header(
+        self, serialization_properties: OpenQASMSerializationProperties
+    ) -> List[str]:
+        ir_instructions = ["OPENQASM 3.0;"]
+        if not self.result_types:
+            ir_instructions.append(f"bit[{self.qubit_count}] b;")
+
+        if serialization_properties.qubit_reference_type == QubitReferenceType.VIRTUAL:
+            total_qubits = max(self.qubits).real + 1
+            ir_instructions.append(f"qubit[{total_qubits}] q;")
+        elif serialization_properties.qubit_reference_type != QubitReferenceType.PHYSICAL:
+            raise ValueError(
+                f"Invalid qubit_reference_type "
+                f"{serialization_properties.qubit_reference_type} supplied."
+            )
+        return ir_instructions
+
     def as_unitary(self) -> np.ndarray:
         r"""
         Returns the unitary matrix representation, in little endian format, of the entire circuit.
