@@ -26,6 +26,11 @@ from braket.aws import AwsQuantumTask
 from braket.aws.aws_quantum_task import _create_annealing_device_params
 from braket.aws.aws_session import AwsSession
 from braket.circuits import Circuit
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    QubitReferenceType,
+)
 from braket.device_schema import GateModelParameters
 from braket.device_schema.dwave import (
     Dwave2000QDeviceParameters,
@@ -435,7 +440,7 @@ def test_from_circuit_with_shots(device_arn, device_parameters_class, aws_sessio
     _assert_create_quantum_task_called_with(
         aws_session,
         device_arn,
-        circuit.to_ir().json(),
+        circuit.to_ir(ir_type=IRType.OPENQASM).json(),
         S3_TARGET,
         shots,
         device_parameters_class(
@@ -464,7 +469,10 @@ def test_from_circuit_with_disabled_rewiring(
     _assert_create_quantum_task_called_with(
         aws_session,
         device_arn,
-        circuit.to_ir().json(),
+        circuit.to_ir(
+            ir_type=IRType.OPENQASM,
+            serialization_properties=OpenQASMSerializationProperties(QubitReferenceType.PHYSICAL),
+        ).json(),
         S3_TARGET,
         shots,
         device_parameters_class(
@@ -497,10 +505,17 @@ def test_from_circuit_with_verbatim(
     )
     assert task == AwsQuantumTask(mocked_task_arn, aws_session)
 
+    serialization_properties = OpenQASMSerializationProperties(
+        qubit_reference_type=QubitReferenceType.PHYSICAL
+    )
+
     _assert_create_quantum_task_called_with(
         aws_session,
         device_arn,
-        circ.to_ir().json(),
+        circ.to_ir(
+            ir_type=IRType.OPENQASM,
+            serialization_properties=serialization_properties,
+        ).json(),
         S3_TARGET,
         shots,
         device_parameters_class(
@@ -795,7 +810,7 @@ def test_create_with_tags(device_arn, device_parameters_class, aws_session, circ
     _assert_create_quantum_task_called_with(
         aws_session,
         device_arn,
-        circuit.to_ir().json(),
+        circuit.to_ir(ir_type=IRType.OPENQASM).json(),
         S3_TARGET,
         shots,
         device_parameters_class(
@@ -855,3 +870,20 @@ def _mock_metadata(aws_session, state):
 
 def _mock_s3(aws_session, result):
     aws_session.retrieve_s3_object_body.return_value = result
+
+
+def test_no_program_inputs(aws_session):
+    openqasm_program = OpenQasmProgram(
+        source="""
+        qubit q;
+        h q;
+        """,
+        inputs={"x": 1},
+    )
+    aws_session.create_quantum_task.return_value = arn
+    shots = 21
+    only_for_local_sim = (
+        "OpenQASM Program inputs are only currently supported in the LocalSimulator."
+    )
+    with pytest.raises(ValueError, match=only_for_local_sim):
+        AwsQuantumTask.create(aws_session, SIMULATOR_ARN, openqasm_program, S3_TARGET, shots)
