@@ -32,6 +32,12 @@ from braket.circuits import (
     gates,
     noise,
 )
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    QubitReferenceType,
+)
+from braket.ir.openqasm import Program as OpenQasmProgram
 
 
 @pytest.fixture
@@ -625,6 +631,124 @@ def test_ir_non_empty_instructions_result_types_basis_rotation_instructions():
     assert circ.to_ir() == expected
 
 
+@pytest.mark.parametrize(
+    "circuit, serialization_properties, expected_ir",
+    [
+        (
+            Circuit().rx(0, 0.15).rx(1, 0.3),
+            OpenQASMSerializationProperties(QubitReferenceType.VIRTUAL),
+            OpenQasmProgram(
+                source="\n".join(
+                    [
+                        "OPENQASM 3.0;",
+                        "bit[2] b;",
+                        "qubit[2] q;",
+                        "rx(0.15) q[0];",
+                        "rx(0.3) q[1];",
+                        "b[0] = measure q[0];",
+                        "b[1] = measure q[1];",
+                    ]
+                )
+            ),
+        ),
+        (
+            Circuit().rx(0, 0.15).rx(4, 0.3),
+            OpenQASMSerializationProperties(QubitReferenceType.PHYSICAL),
+            OpenQasmProgram(
+                source="\n".join(
+                    [
+                        "OPENQASM 3.0;",
+                        "bit[2] b;",
+                        "rx(0.15) $0;",
+                        "rx(0.3) $4;",
+                        "b[0] = measure $0;",
+                        "b[1] = measure $4;",
+                    ]
+                )
+            ),
+        ),
+        (
+            Circuit()
+            .rx(0, 0.15)
+            .add_verbatim_box(Circuit().rx(4, 0.3))
+            .expectation(observable=Observable.I()),
+            OpenQASMSerializationProperties(QubitReferenceType.PHYSICAL),
+            OpenQasmProgram(
+                source="\n".join(
+                    [
+                        "OPENQASM 3.0;",
+                        "rx(0.15) $0;",
+                        "#pragma braket verbatim",
+                        "box{",
+                        "rx(0.3) $4;",
+                        "}",
+                        "#pragma braket result expectation i all",
+                    ]
+                )
+            ),
+        ),
+        (
+            Circuit()
+            .rx(0, 0.15)
+            .rx(4, 0.3)
+            .bit_flip(3, probability=0.2)
+            .expectation(observable=Observable.I(), target=0),
+            None,
+            OpenQasmProgram(
+                source="\n".join(
+                    [
+                        "OPENQASM 3.0;",
+                        "qubit[5] q;",
+                        "rx(0.15) q[0];",
+                        "rx(0.3) q[4];",
+                        "#pragma braket noise bit_flip(0.2) q[3]",
+                        "#pragma braket result expectation i(q[0])",
+                    ]
+                )
+            ),
+        ),
+    ],
+)
+def test_circuit_to_ir_openqasm(circuit, serialization_properties, expected_ir):
+    assert (
+        circuit.to_ir(ir_type=IRType.OPENQASM, serialization_properties=serialization_properties)
+        == expected_ir
+    )
+
+
+@pytest.mark.parametrize(
+    "ir_type, serialization_properties, expected_exception, expected_message",
+    [
+        (
+            "invalid-ir-type",
+            OpenQASMSerializationProperties(QubitReferenceType.VIRTUAL),
+            ValueError,
+            "Supplied ir_type invalid-ir-type is not supported.",
+        ),
+        (
+            IRType.OPENQASM,
+            OpenQASMSerializationProperties("invalid-qubit-reference-type"),
+            ValueError,
+            "Invalid qubit_reference_type invalid-qubit-reference-type supplied.",
+        ),
+        (
+            IRType.OPENQASM,
+            "invalid-serialization-properties",
+            ValueError,
+            "serialization_properties must be of type OpenQASMSerializationProperties "
+            "for IRType.OPENQASM.",
+        ),
+    ],
+)
+def test_circuit_to_ir_invalid_inputs(
+    ir_type, serialization_properties, expected_exception, expected_message
+):
+    circuit = Circuit().h(0).cnot(0, 1)
+    with pytest.raises(expected_exception) as exc:
+        circuit.to_ir(ir_type, serialization_properties=serialization_properties)
+    assert exc.value.args[0] == expected_message
+
+
 def test_as_unitary_empty_instructions_returns_empty_array():
     circ = Circuit()
     circ.as_unitary() == []
